flutter_add_to_cart_button library
Classes
- AddToCartButton
- Help you create a button that is used to let the users can add items to their shopping cart. This will be useful for eCommerce app.
Enums
- AddToCartButtonStateId
- This is used to control the button state.